==> tuia-advert-center-api-1.5.0-20180627.100254-47-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/account/DataSnapshotCountDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.account;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年11月16日 09:52
 * @descript:
 * @version: 1.0
 */
public class DataSnapshotCountDto {

    /**
     * 存入
     */
    private Long balanceIn;

    /**
     * 支出
     */
    private Long balanceOut;

    /**
     * 存入 --- 现金
     */
    private Long balanceInCash;

    /**
     * 存入 --- 返货
     */
    private Long balanceInBackCash;

    /**
     * 存入 --- 现金 --- 充值
     */
    private Long balanceInCashRecharge;

    /**
     * 存入 --- 现金 --- 其它
     */
    private Long balanceInCashOther;

    /**
     * 存入 --- 返货 --- 充值
     */
    private Long balanceInBackRecharge;

    /**
     * 存入 --- 返货 --- 其它
     */
    private Long balanceInBackOther;

    /**
     * 支出 --- 现金
     */
    private Long balanceOutCash;

    /**
     * 支出 --- 返货
     */
    private Long balanceOutBackCash;

    /**
     * 支出 --- 现金 --- 消耗
     */
    private Long balanceOutCashConsume;

    /**
     * 支出 --- 现金 --- 其它
     */
    private Long balanceOutCashOther;

    /**
     * 支出 --- 返货 --- 消耗
     */
    private Long balanceOutBackConsume;

    /**
     * 支出 --- 返货 --- 其它
     */
    private Long balanceOutBackOther;

    /**
     * 期初总余额
     */
    private Long beginTotal;

    /**
     * 期初余额 --- 返货
     */
    private Long beginBack;

    /**
     * 期末总余额
     */
    private Long endTotal;

    /**
     * 期末余额 --- 返回
     */
    private Long endBack;

    /**
     *  期初余额 --- 现金
     */
    private Long beginCash;

    /**
     *  期末余额 --- 现金
     */
    private Long endCash;

    public Long getBalanceIn() {
        return balanceIn;
    }

    public void setBalanceIn(Long balanceIn) {
        this.balanceIn = balanceIn;
    }

    public Long getBalanceOut() {
        return balanceOut;
    }

    public void setBalanceOut(Long balanceOut) {
        this.balanceOut = balanceOut;
    }

    public Long getBalanceInCash() {
        return balanceInCash;
    }

    public void setBalanceInCash(Long balanceInCash) {
        this.balanceInCash = balanceInCash;
    }

    public Long getBalanceInBackCash() {
        return balanceInBackCash;
    }

    public void setBalanceInBackCash(Long balanceInBackCash) {
        this.balanceInBackCash = balanceInBackCash;
    }

    public Long getBalanceInCashRecharge() {
        return balanceInCashRecharge;
    }

    public void setBalanceInCashRecharge(Long balanceInCashRecharge) {
        this.balanceInCashRecharge = balanceInCashRecharge;
    }

    public Long getBalanceInCashOther() {
        return balanceInCashOther;
    }

    public void setBalanceInCashOther(Long balanceInCashOther) {
        this.balanceInCashOther = balanceInCashOther;
    }

    public Long getBalanceInBackRecharge() {
        return balanceInBackRecharge;
    }

    public void setBalanceInBackRecharge(Long balanceInBackRecharge) {
        this.balanceInBackRecharge = balanceInBackRecharge;
    }

    public Long getBalanceInBackOther() {
        return balanceInBackOther;
    }

    public void setBalanceInBackOther(Long balanceInBackOther) {
        this.balanceInBackOther = balanceInBackOther;
    }

    public Long getBalanceOutCash() {
        return balanceOutCash;
    }

    public void setBalanceOutCash(Long balanceOutCash) {
        this.balanceOutCash = balanceOutCash;
    }

    public Long getBalanceOutBackCash() {
        return balanceOutBackCash;
    }

    public void setBalanceOutBackCash(Long balanceOutBackCash) {
        this.balanceOutBackCash = balanceOutBackCash;
    }

    public Long getBalanceOutCashConsume() {
        return balanceOutCashConsume;
    }

    public void setBalanceOutCashConsume(Long balanceOutCashConsume) {
        this.balanceOutCashConsume = balanceOutCashConsume;
    }

    public Long getBalanceOutCashOther() {
        return balanceOutCashOther;
    }

    public void setBalanceOutCashOther(Long balanceOutCashOther) {
        this.balanceOutCashOther = balanceOutCashOther;
    }

    public Long getBalanceOutBackConsume() {
        return balanceOutBackConsume;
    }

    public void setBalanceOutBackConsume(Long balanceOutBackConsume) {
        this.balanceOutBackConsume = balanceOutBackConsume;
    }

    public Long getBalanceOutBackOther() {
        return balanceOutBackOther;
    }

    public void setBalanceOutBackOther(Long balanceOutBackOther) {
        this.balanceOutBackOther = balanceOutBackOther;
    }

    public Long getBeginTotal() {
        return beginTotal;
    }

    public void setBeginTotal(Long beginTotal) {
        this.beginTotal = beginTotal;
    }

    public Long getBeginBack() {
        return beginBack;
    }

    public void setBeginBack(Long beginBack) {
        this.beginBack = beginBack;
    }

    public Long getEndTotal() {
        return endTotal;
    }

    public void setEndTotal(Long endTotal) {
        this.endTotal = endTotal;
    }

    public Long getEndBack() {
        return endBack;
    }

    public void setEndBack(Long endBack) {
        this.endBack = endBack;
    }

    public Long getBeginCash() {
        return beginCash;
    }

    public void setBeginCash(Long beginCash) {
        this.beginCash = beginCash;
    }

    public Long getEndCash() {
        return endCash;
    }

    public void setEndCash(Long endCash) {
        this.endCash = endCash;
    }
}

==> tuia-advert-center-api-2.2.22-sources.jar: cn/com/duiba/tuia/core/api/dto/rsp/account/DataSnapshotCountDto.java <==
package cn.com.duiba.tuia.core.api.dto.rsp.account;

import java.io.Serializable;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年11月16日 09:52
 * @descript:
 * @version: 1.0
 */
public class DataSnapshotCountDto  implements Serializable {

    private static final long serialVersionUID = -2602386843335767838L;
    /**
     * 存入
     */
    private Long balanceIn;

    /**
     * 支出
     */
    private Long balanceOut;

    /**
     * 存入 --- 现金
     */
    private Long balanceInCash;

    /**
     * 存入 --- 返货
     */
    private Long balanceInBackCash;

    /**
     * 存入 --- 现金 --- 充值
     */
    private Long balanceInCashRecharge;

    /**
     * 存入 --- 现金 --- 其它
     */
    private Long balanceInCashOther;

    /**
     * 存入 --- 返货 --- 充值
     */
    private Long balanceInBackRecharge;

    /**
     * 存入 --- 返货 --- 其它
     */
    private Long balanceInBackOther;

    /**
     * 支出 --- 现金
     */
    private Long balanceOutCash;

    /**
     * 支出 --- 返货
     */
    private Long balanceOutBackCash;

    /**
     * 支出 --- 现金 --- 消耗
     */
    private Long balanceOutCashConsume;

    /**
     * 支出 --- 现金 --- 其它
     */
    private Long balanceOutCashOther;

    /**
     * 支出 --- 返货 --- 消耗
     */
    private Long balanceOutBackConsume;

    /**
     * 支出 --- 返货 --- 其它
     */
    private Long balanceOutBackOther;

    /**
     * 期初总余额
     */
    private Long beginTotal;

    /**
     * 期初余额 --- 返货
     */
    private Long beginBack;

    /**
     * 期末总余额
     */
    private Long endTotal;

    /**
     * 期末余额 --- 返回
     */
    private Long endBack;

    /**
     *  期初余额 --- 现金
     */
    private Long beginCash;

    /**
     *  期末余额 --- 现金
     */
    private Long endCash;

    public Long getBalanceIn() {
        return balanceIn;
    }

    public void setBalanceIn(Long balanceIn) {
        this.balanceIn = balanceIn;
    }

    public Long getBalanceOut() {
        return balanceOut;
    }

    public void setBalanceOut(Long balanceOut) {
        this.balanceOut = balanceOut;
    }

    public Long getBalanceInCash() {
        return balanceInCash;
    }

    public void setBalanceInCash(Long balanceInCash) {
        this.balanceInCash = balanceInCash;
    }

    public Long getBalanceInBackCash() {
        return balanceInBackCash;
    }

    public void setBalanceInBackCash(Long balanceInBackCash) {
        this.balanceInBackCash = balanceInBackCash;
    }

    public Long getBalanceInCashRecharge() {
        return balanceInCashRecharge;
    }

    public void setBalanceInCashRecharge(Long balanceInCashRecharge) {
        this.balanceInCashRecharge = balanceInCashRecharge;
    }

    public Long getBalanceInCashOther() {
        return balanceInCashOther;
    }

    public void setBalanceInCashOther(Long balanceInCashOther) {
        this.balanceInCashOther = balanceInCashOther;
    }

    public Long getBalanceInBackRecharge() {
        return balanceInBackRecharge;
    }

    public void setBalanceInBackRecharge(Long balanceInBackRecharge) {
        this.balanceInBackRecharge = balanceInBackRecharge;
    }

    public Long getBalanceInBackOther() {
        return balanceInBackOther;
    }

    public void setBalanceInBackOther(Long balanceInBackOther) {
        this.balanceInBackOther = balanceInBackOther;
    }

    public Long getBalanceOutCash() {
        return balanceOutCash;
    }

    public void setBalanceOutCash(Long balanceOutCash) {
        this.balanceOutCash = balanceOutCash;
    }

    public Long getBalanceOutBackCash() {
        return balanceOutBackCash;
    }

    public void setBalanceOutBackCash(Long balanceOutBackCash) {
        this.balanceOutBackCash = balanceOutBackCash;
    }

    public Long getBalanceOutCashConsume() {
        return balanceOutCashConsume;
    }

    public void setBalanceOutCashConsume(Long balanceOutCashConsume) {
        this.balanceOutCashConsume = balanceOutCashConsume;
    }

    public Long getBalanceOutCashOther() {
        return balanceOutCashOther;
    }

    public void setBalanceOutCashOther(Long balanceOutCashOther) {
        this.balanceOutCashOther = balanceOutCashOther;
    }

    public Long getBalanceOutBackConsume() {
        return balanceOutBackConsume;
    }

    public void setBalanceOutBackConsume(Long balanceOutBackConsume) {
        this.balanceOutBackConsume = balanceOutBackConsume;
    }

    public Long getBalanceOutBackOther() {
        return balanceOutBackOther;
    }

    public void setBalanceOutBackOther(Long balanceOutBackOther) {
        this.balanceOutBackOther = balanceOutBackOther;
    }

    public Long getBeginTotal() {
        return beginTotal;
    }

    public void setBeginTotal(Long beginTotal) {
        this.beginTotal = beginTotal;
    }

    public Long getBeginBack() {
        return beginBack;
    }

    public void setBeginBack(Long beginBack) {
        this.beginBack = beginBack;
    }

    public Long getEndTotal() {
        return endTotal;
    }

    public void setEndTotal(Long endTotal) {
        this.endTotal = endTotal;
    }

    public Long getEndBack() {
        return endBack;
    }

    public void setEndBack(Long endBack) {
        this.endBack = endBack;
    }

    public Long getBeginCash() {
        return beginCash;
    }

    public void setBeginCash(Long beginCash) {
        this.beginCash = beginCash;
    }

    public Long getEndCash() {
        return endCash;
    }

    public void setEndCash(Long endCash) {
        this.endCash = endCash;
    }
}
